# Changelog

## v2021.12.16

([full changelog](https://github.com/NCAR/xpersist/compare/e3154e12df7c881623af24ff33b09ead5df5277c...348f3743dd5d79a84a861f0318a234a9e2ca2d35))

### Enhancements made

- Record additional metadata when caching artifact [#48](https://github.com/NCAR/xpersist/pull/48) ([@andersy005](https://github.com/andersy005))
- Add `get_artifact()` method [#45](https://github.com/NCAR/xpersist/pull/45) ([@andersy005](https://github.com/andersy005))
- Properly use kwargs for prefect's result target templating [#41](https://github.com/NCAR/xpersist/pull/41) ([@norlandrhagen](https://github.com/norlandrhagen))
- Move caching functionality from NCAR/esds-funnel [#37](https://github.com/NCAR/xpersist/pull/37) ([@andersy005](https://github.com/andersy005))

### Maintenance and upkeep improvements

- Update PyPI release workflow [#50](https://github.com/NCAR/xpersist/pull/50) ([@andersy005](https://github.com/andersy005))
- Update CI [#36](https://github.com/NCAR/xpersist/pull/36) ([@andersy005](https://github.com/andersy005))
- [pre-commit.ci] pre-commit autoupdate [#34](https://github.com/NCAR/xpersist/pull/34) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#32](https://github.com/NCAR/xpersist/pull/32) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#31](https://github.com/NCAR/xpersist/pull/31) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#30](https://github.com/NCAR/xpersist/pull/30) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#29](https://github.com/NCAR/xpersist/pull/29) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#28](https://github.com/NCAR/xpersist/pull/28) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#27](https://github.com/NCAR/xpersist/pull/27) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- 💚 CI overhaul [#12](https://github.com/NCAR/xpersist/pull/12) ([@andersy005](https://github.com/andersy005))
- Set up Github Action CI [#2](https://github.com/NCAR/xpersist/pull/2) ([@andersy005](https://github.com/andersy005))

### Documentation improvements

- Record additional metadata when caching artifact [#48](https://github.com/NCAR/xpersist/pull/48) ([@andersy005](https://github.com/andersy005))
- Add docs on target templating [#47](https://github.com/NCAR/xpersist/pull/47) ([@andersy005](https://github.com/andersy005))
- Update docs [#46](https://github.com/NCAR/xpersist/pull/46) ([@andersy005](https://github.com/andersy005))
- Update README [#44](https://github.com/NCAR/xpersist/pull/44) ([@andersy005](https://github.com/andersy005))
- Add how to use XpersistResult to the docs [#42](https://github.com/NCAR/xpersist/pull/42) ([@andersy005](https://github.com/andersy005))
- Add Tutorial to docs [#40](https://github.com/NCAR/xpersist/pull/40) ([@andersy005](https://github.com/andersy005))
- Add sphinx docs [#39](https://github.com/NCAR/xpersist/pull/39) ([@andersy005](https://github.com/andersy005))

### Other merged PRs

- [pre-commit.ci] pre-commit autoupdate [#33](https://github.com/NCAR/xpersist/pull/33) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 2.0.3 to 2.1.0 [#26](https://github.com/NCAR/xpersist/pull/26) ([@dependabot](https://github.com/dependabot))
- [pre-commit.ci] pre-commit autoupdate [#25](https://github.com/NCAR/xpersist/pull/25) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- [pre-commit.ci] pre-commit autoupdate [#24](https://github.com/NCAR/xpersist/pull/24) ([@pre-commit-ci](https://github.com/pre-commit-ci))
- Bump codecov/codecov-action from 2.0.2 to 2.0.3 [#23](https://github.com/NCAR/xpersist/pull/23) ([@dependabot](https://github.com/dependabot))
- Bump styfle/cancel-workflow-action from 0.9.0 to 0.9.1 [#22](https://github.com/NCAR/xpersist/pull/22) ([@dependabot](https://github.com/dependabot))
- Bump codecov/codecov-action from 1 to 2.0.2 [#21](https://github.com/NCAR/xpersist/pull/21) ([@dependabot](https://github.com/dependabot))
- Bump pre-commit/action from v2.0.2 to v2.0.3 [#20](https://github.com/NCAR/xpersist/pull/20) ([@dependabot](https://github.com/dependabot))
- Bump styfle/cancel-workflow-action from 0.8.0 to 0.9.0 [#19](https://github.com/NCAR/xpersist/pull/19) ([@dependabot](https://github.com/dependabot))
- Bump pre-commit/action from v2.0.0 to v2.0.2 [#18](https://github.com/NCAR/xpersist/pull/18) ([@dependabot](https://github.com/dependabot))
- Bump styfle/cancel-workflow-action from 0.7.0 to 0.8.0 [#16](https://github.com/NCAR/xpersist/pull/16) ([@dependabot](https://github.com/dependabot))
- Bump styfle/cancel-workflow-action from 0.6.0 to 0.7.0 [#15](https://github.com/NCAR/xpersist/pull/15) ([@dependabot](https://github.com/dependabot))
- Add introspection functions for extracting function information [#14](https://github.com/NCAR/xpersist/pull/14) ([@andersy005](https://github.com/andersy005))
- ⚡ Create LICENSE [#13](https://github.com/NCAR/xpersist/pull/13) ([@andersy005](https://github.com/andersy005))
- Add support for caching datasets as zarr stores [#4](https://github.com/NCAR/xpersist/pull/4) ([@andersy005](https://github.com/andersy005))
- Patch CI [#3](https://github.com/NCAR/xpersist/pull/3) ([@andersy005](https://github.com/andersy005))

### Contributors to this release

([GitHub contributors page for this release](https://github.com/NCAR/xpersist/graphs/contributors?from=2019-11-01&to=2021-12-16&type=c))

[@andersy005](https://github.com/search?q=repo%3ANCAR%2Fxpersist+involves%3Aandersy005+updated%3A2019-11-01..2021-12-16&type=Issues) | [@dependabot](https://github.com/search?q=repo%3ANCAR%2Fxpersist+involves%3Adependabot+updated%3A2019-11-01..2021-12-16&type=Issues) | [@norlandrhagen](https://github.com/search?q=repo%3ANCAR%2Fxpersist+involves%3Anorlandrhagen+updated%3A2019-11-01..2021-12-16&type=Issues) | [@pre-commit-ci](https://github.com/search?q=repo%3ANCAR%2Fxpersist+involves%3Apre-commit-ci+updated%3A2019-11-01..2021-12-16&type=Issues)
